Interface: ParsingOptions | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: ParsingOptions

## # Hierarchy

- `ParsingOptions`

  ↳ `ControllerDatasetOptions`

  ↳ `CoreChartOptions`

## # Properties

### # normalized

• normalized: `boolean`

Chart.js is fastest if you provide data with indices that are unique, sorted, and consistent across datasets and provide the normalized: true option to let Chart.js know that you have done so.

#### # Defined in

index.esm.d.ts:58
(opens new window)

### # parsing

• parsing: `false` | { [key: string]: `string`; }

How to parse the dataset. The parsing can be disabled by specifying parsing: false at chart options or dataset. If parsing is disabled, data must be sorted and in the formats the associated chart type and scales use internally.

#### # Defined in

index.esm.d.ts:49
(opens new window)